==> lyskom-1.6.4.tar.gz: lyskom-1.6.4/src/server/async.h <==
/*
 * $Id: async.h,v 0.3 1991/09/15 10:33:18 linus Exp $
 * Copyright (C) 1991  Lysator Academic Computer Association.
 *
 * This file is part of the LysKOM server.
 * 
 * LysKOM is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 1, or (at your option) 
 * any later version.
 * 
 * LysKOM is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with LysKOM; see the file COPYING.  If not, write to
 * Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
 * or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
 * MA 02139, USA.
 *
 * Please mail bug reports to bug-lyskom@lysator.liu.se. 
 */
/*
 * $Id: async.h,v 0.3 1991/09/15 10:33:18 linus Exp $
 *
 * This file contains the parts of the async protocol that are common
 * to the server and the client.
 */


/*
 * What does this packet contain? (See doc/com-spec)
 */
typedef enum {
	ay_new_text = 0,
	ay_i_am_off = 1,	/* Obsoleted by ay_logout */
	ay_i_am_on_obsolete = 2, /* Sends a Who_info_old. */
	ay_conf_deleted = 3,
	ay_conf_created = 4,
	ay_new_name = 5,
	ay_i_am_on = 6,		/* Sends a Who_info when changeinge
				   conference or what-am-i-doing. */
	ay_sync_db = 7,		/* Database is syncing. */
	ay_leave_conf = 8,
	ay_login = 9,		/* Sends a Pers_no and connection
				   when someone logs in. */
	ay_broadcast = 10,	/* Sends Pers_no of sender and a string. */
	ay_rejected_connection = 11,
				/* A connection attempt was rejected
	       			   because LysKOM is full. */
	ay_send_message = 12,	/* A message is sent. */
	ay_logout = 13		/* Someone logs out. */
} Async;

==> lyskom-1.7.1.tar.gz: lyskom-1.7.1/src/server/async.h <==
/*
 * $Id: async.h,v 0.6 1995/01/01 20:17:19 ceder Exp $
 * Copyright (C) 1991, 1994, 1995  Lysator Academic Computer Association.
 *
 * This file is part of the LysKOM server.
 * 
 * LysKOM is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 1, or (at your option) 
 * any later version.
 * 
 * LysKOM is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with LysKOM; see the file COPYING.  If not, write to
 * Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
 * or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
 * MA 02139, USA.
 *
 * Please mail bug reports to bug-lyskom@lysator.liu.se. 
 */
/*
 * $Id: async.h,v 0.6 1995/01/01 20:17:19 ceder Exp $
 *
 * This file contains the parts of the async protocol that are common
 * to the server and the client.
 */


/*
 * What does this packet contain? (See doc/com-spec)
 */
typedef enum {
	ay_new_text = 0,
			 	 /* 1 is no longer used. */
			 	 /* 2 is no longer used. */
#if 0
	ay_conf_deleted = 3,	/* Reserved for future use. */
	ay_conf_created = 4,	/* Reserved for future use. */
#endif	
	ay_new_name = 5,
	ay_i_am_on = 6,		/* Sends a Who_info when changeinge
				   conference or what-am-i-doing. */
	ay_sync_db = 7,		/* Database is syncing. */
	ay_leave_conf = 8,
	ay_login = 9,		/* Sends a Pers_no and connection
				   when someone logs in. */
				/* 10 is no longer used. */
	ay_rejected_connection = 11,
				/* A connection attempt was rejected
	       			   because LysKOM is full. */
	ay_send_message = 12,	/* A message is sent. */
	ay_logout = 13		/* Someone logs out. */
} Async;
